@@ -16,12 +16,14 @@ lystig <- function(init,A,B,ntimes=NULL,stationary=TRUE) {
 	# IN COMPUTING ALPHA AND BETA BUT IS NOW NECCESSARY IN COMPUTING XI
 	# A = K*K matrix with transition probabilities, from column to row !!!!!!!
 	# change to T*K*K
-	
-	# B = T*K matrix with elements ab_{ij} = P(y_i|s_j)
+		
+	B <- apply(B,c(1,3),prod)
+
+	# B = T*K*nresp matrix with elements ab_{tij} = P(y_t_i|s_j)
 	# init = K vector with initial probabilities !!!OR!!! K*length(ntimes) matrix with initial probs per case
 	# Returns: 'sca'le factors, recurrent variables 'phi', loglikelihood
-	
-	nt <- nrow(B)	
+		
+	nt <- nrow(B)
 	ns <- ncol(init)
 		
 	if(!is.null(ntimes)) {
@@ -32,10 +34,10 @@ lystig <- function(init,A,B,ntimes=NULL,stationary=TRUE) {
 		et <- cumsum(ntimes)
 		bt <- c(1,et[-lt]+1)
 				
-		ll <- 0
-				
+		ll <- 0		
+		
 		for(case in 1:lt) { # multiple cases
-			phi[bt[case],] <- init[case,]*B[bt[case],] # initialize
+			phi[bt[case],] <- init[case,]*B[bt[case],] # initialize case
 			sca[bt[case]] <- 1/sum(phi[bt[case],])
 			if(ntimes[case]>1) {
 				for(i in (bt[case]+1):et[case]) {
