@@ -50,15 +50,25 @@ setMethod("GLMresponse",
 		if(family$family=="multinomial") {
 			y <- model.response(mf)
 			if(NCOL(y) == 1) {
-				if(is.factor(y)) y <- model.matrix(~y-1) else {
-					if(!is.numeric(y)) stop("model response not valid for binomial model")
+				if(is.factor(y)) {
+					y <- model.matrix(~y-1) 
+				} else {
+					if(!is.numeric(y)) stop("model response not valid for multinomial model")
 					y <- model.matrix(~factor(y)-1)
 				}
 			}
-			parameters$coefficients <- matrix(0,ncol=ncol(y),nrow=ncol(x))
-			if(is.null(fixed)) {
-				fixed <- parameters$coefficients
-				fixed[,family$base] <- 1 
+			if(family$link=="mlogit") {				
+				parameters$coefficients <- matrix(0,ncol=ncol(y),nrow=ncol(x))
+				if(is.null(fixed)) {
+					fixed <- parameters$coefficients
+					fixed[,family$base] <- 1 
+					fixed <- c(as.logical(t(fixed)))
+				}
+			}
+			if(family$link=="identity") {
+				if(ncol(x)>1) stop("covariates not allowed in multinomial model with identity link")
+				parameters$coefficients <- matrix(1/ncol(y),ncol=ncol(y),1)
+				fixed <- c(rep(0,ncol(y)-1),1) # this needs to be fixed at some point using contraints
 				fixed <- c(as.logical(t(fixed)))
 			}
 		}
@@ -76,16 +86,16 @@ setMethod("GLMresponse",
 				if(ncol(x)>1) parameters$coefficients[2:ncol(x),] <- pstart[2:ncol(x),]
 			} else {
 				# if(prob) parameters$coefficients <- family$linkfun(as.numeric(pstart[1:length(parameters$coefficients)]))
-  			if(family$family=="binomial") {
-  				if(prob) parameters$coefficients[1] <- family$linkfun(pstart[1])
-  				else parameters$coefficients[1] <- pstart[1]
-  				if(ncol(x)>1) parameters$coefficients[2:ncol(x)] <- pstart[2:ncol(x)]
-  			} else {
-          parameters$coefficients[1:ncol(x)] <- pstart[1:ncol(x)]
-  			}
-  			if(length(unlist(parameters))>length(parameters$coefficients)) {
-  				if(family$family=="gaussian") parameters$sd <- as.numeric(pstart[(length(parameters$coefficients)+1)])
-  			}
+				if(family$family=="binomial") {
+					if(prob) parameters$coefficients[1] <- family$linkfun(pstart[1])
+					else parameters$coefficients[1] <- pstart[1]
+					if(ncol(x)>1) parameters$coefficients[2:ncol(x)] <- pstart[2:ncol(x)]
+				} else {
+					parameters$coefficients[1:ncol(x)] <- pstart[1:ncol(x)]
+				}
+				if(length(unlist(parameters))>length(parameters$coefficients)) {
+					if(family$family=="gaussian") parameters$sd <- as.numeric(pstart[(length(parameters$coefficients)+1)])
+				}
 			}
 		}
 		mod <- switch(family$family,
@@ -106,7 +116,7 @@ setMethod("show","GLMresponse",
 		print(object@formula)
 		cat("Coefficients: \n")
 		print(object@parameters$coefficients)
-		if(object@family$family=="multinomial") {
+		if(object@family$family=="multinomial"&object@family$link!="identity") {
 			# also print probabilities at covariate values of zero
 			cat("Probalities at zero values of the covariates.\n")
 			if(!(is.null(dim(object@parameters$coefficients)))) {
@@ -143,10 +153,9 @@ setMethod("setpars","GLMresponse",
 			"pars"= {
 				if(object@family$family=="multinomial") {
 					object@parameters$coefficients <- matrix(values,ncol(object@x),byrow=TRUE)
-					if(prob) object@parameters$coefficients[1,] <- object@family$linkfun(values[1:ncol(object@parameters$coefficients)],base=object@family$base)
-# 					object@parameters$coefficients[1,] <- values[1:ncol(object@parameters$coefficients)]
-# 					values <- matrix(values,,ncol(object@x),byrow=TRUE)
-# 					if(ncol(object@x)>1) object@parameters$coefficients[2:ncol(object@x),] <- values[2:ncol(object@x),]
+					if(object@family$link=="mlogit") {	
+						if(prob) object@parameters$coefficients[1,] <- object@family$linkfun(values[1:ncol(object@parameters$coefficients)],base=object@family$base)
+					}
 				} else {
 					object@parameters$coefficients <- values[1:length(object@parameters$coefficients)] # matrix(values,ncol(object@x),byrow=TRUE) # this needs fixing!!!!
 				}
