@@ -78,8 +78,8 @@ setMethod("predict","transInit",
 			if(object@family$link=="identity") object@family$linkinv(object@x%*%object@parameters$coefficients)
 			else object@family$linkinv(object@x%*%object@parameters$coefficients,base=object@family$base)
 		} else {
-			if(!(is.matrix(newx))) stop("'newx' must be matrix in predict (GLMresponse)")
-			if(!(ncol(newx)==nrow(object@parameters$coefficients))) stop("Incorrect dimension of 'newx' in predict (GLMresponse)")
+			if(!(is.matrix(newx))) stop("'newx' must be matrix in predict(transInit)")
+			if(!(ncol(newx)==nrow(object@parameters$coefficients))) stop("Incorrect dimension of 'newx' in predict(transInit)")
 			if(object@family$link=="identity") object@family$linkinv(newx%*%object@parameters$coefficients)
 			else object@family$linkinv(newx%*%object@parameters$coefficients,base=object@family$base)
 		}
